@@ -27,8 +27,11 @@ def setup(default_scene : PyGameScene,window_name="PyGameUI Window"):
                 scene_handler.current_scene.update()
         if running:
             running = scene_handler.current_scene.render(screen,events)
+
+        if not running:
+            scene_handler.current_scene.close()
         pygame.display.update()
-        clock.tick(scene_handler.FPS)
+        scene_handler.delta = clock.tick(scene_handler.FPS)
 
 
 if __name__ == "__main__":
